@@ -3,12 +3,12 @@
 # Eric Hameleers <alien@slackware.com> (encryption support)
 
 LIVELABEL="LIVE" #edit in init script too
-#SLACKEL_FLAVOR="Slackel-kde-7.7.0"
+#SLACKEL_FLAVOR="Slackel-kde-8.0"
 #SLACKEL_FLAVOR_LILO="Slackel-kde"
-#SLACKEL_FLAVOR="Slackel-openbox-7.7.0"
-#SLACKEL_FLAVOR_LILO="Slackel-openbox"
-SLACKEL_FLAVOR="Slackel-mate-7.7.0"
-SLACKEL_FLAVOR_LILO="Slackel-mate"
+SLACKEL_FLAVOR="Slackel-openbox-8.0"
+SLACKEL_FLAVOR_LILO="Slackel-openbox"
+#SLACKEL_FLAVOR="Slackel-mate-8.0"
+#SLACKEL_FLAVOR_LILO="Slackel-mate"
 
 #LIVEFSOPTS="-O ^has_journal"
 
@@ -645,12 +645,15 @@ function install_system() {
 	fi
 	#Copy end
 	#################
+	if [ -f /etc/os-release ]; then
+	 cp /etc/os-release /mnt/install/etc/os-release
+	fi 
 	ROOTPART=$(lsblk -l -o name,mountpoint| grep /mnt/install$|sed "s,\([^[:space:]]*\).*,/dev/\1,")
 	ROOTNAME=$(echo $ROOTPART|sed "s,/dev/,,")
 	ROOTUUID=$(lsblk -l -o name,uuid|grep ^$ROOTNAME|sed "s/[^ ]*[[:space:]]*//")
 	#FSTYPE=$(lsblk -l -o name,fstype|grep ^$ROOTNAME|sed "s/[^ ]*[[:space:]]*//")
-	#ROOTDEVICE=/dev/$(lsblk -l -o name,pkname|grep ^$ROOTNAME|sed "s/[^ ]*[[:space:]]*//")
-	#BRAND=$(grep ^NAME /mnt/etc/os-release|sed "s/.*=//")
+	ROOTDEVICE=/dev/$(lsblk -l -o name,pkname|grep ^$ROOTNAME|sed "s/[^ ]*[[:space:]]*//")
+	BRAND=$(grep ^NAME /mnt/install/etc/os-release|sed "s/.*=//")
 	#################
 	echo "Setting up fstab"
 	#FSTab begin
@@ -764,8 +767,13 @@ EOF
 	#InitRD end
    if [ "$bootloader" == "lilo" ]; then
 	#LiLo begin
+	# Create initrd image for (e)lilo
+	sed -i "s/^GENINITRD_INITRD_GZ_SYMLINK=.*/GENINITRD_INITRD_GZ_SYMLINK=true/" /mnt/install/etc/default/geninitrd
+	echo "Create initrd image for (e)lilo"
+	chroot /mnt/install geninitrd
 	if [ "$loadersetup" == "-auto" ]; then
-		installdevice=`echo $systempart | cut -c1-8`
+		#installdevice=`echo $systempart | cut -c1-8`
+        installdevice=$ROOTDEVICE
 		echo "Setting (e)Lilo"
 		if [ -d /sys/firmware/efi ]; then #UEFI
 			if [ "$(/bin/ls /sys/firmware/efi/efivars 2> /dev/null | wc -l)" = "0" ]; then
@@ -796,9 +804,9 @@ timeout=1
 default=$SLACKEL_FLAVOR
 
 image=vmlinuz
-    label=$SLACKEL_FLAVOR
-    append="root=$systempart ro"
-	read-only
+label=$SLACKEL_FLAVOR
+append="root=UUID=$ROOTUUID ro"
+read-only
 EOF
 
 				#####
@@ -811,7 +819,7 @@ EOF
 				#####
 				
 				if [ -f /mnt/install/boot/initrd.gz ]; then
-					echo "  initrd=/boot/initrd.gz" >> /mnt/efi/EFI/$efilabel/elilo.conf
+					echo "initrd=initrd.gz" >> /mnt/efi/EFI/$efilabel/elilo.conf
 					cp /mnt/install/boot/initrd.gz /mnt/efi/EFI/$efilabel/
 				fi
 				
@@ -835,16 +843,16 @@ default=$SLACKEL_FLAVOR
 
 image=/EFI/BOOT/vmlinuz
     label=$SLACKEL_FLAVOR
-    append="root=$systempart ro"
+    append="root=UUID=$ROOTUUID ro"
 	read-only
 	initrd=/EFI/BOOT/initrd.gz
 EOF
 
-				if [ "$installdevice" != "/dev/sdb" ]; then
-						real_device=`echo $installdevice | cut -c6-8`
-						sed -i "s/$real_device/sdb/g" /mnt/efi/EFI/BOOT/elilo.conf
-						#sed -i "s/$real_device/sdb/g" /mnt/install/etc/fstab
-				fi
+				#if [ "$installdevice" != "/dev/sdb" ]; then
+				#		real_device=`echo $installdevice | cut -c6-8`
+				#		sed -i "s/$real_device/sdb/g" /mnt/efi/EFI/BOOT/elilo.conf
+				#		#sed -i "s/$real_device/sdb/g" /mnt/install/etc/fstab
+				#fi
 				umount /mnt/efi
 				rmdir /mnt/efi
 			fi	
@@ -893,12 +901,12 @@ EOF
 			chroot /mnt/install lilo || return $BOOTERROR
 			#chroot /mnt/install umount /proc
 			#####
-			if [ "$installdevice" != "/dev/sda" ]; then
-				if [ "$installdevice" != "/dev/sdb" ]; then
-					real_device=`echo $installdevice | cut -c6-8`
-					sed -i "s/$real_device/sdb/g" /mnt/install/etc/lilo.conf
-				fi
-			fi
+			#if [ "$installdevice" != "/dev/sda" ]; then
+			#	if [ "$installdevice" != "/dev/sdb" ]; then
+			#		real_device=`echo $installdevice | cut -c6-8`
+			#		sed -i "s/$real_device/sdb/g" /mnt/install/etc/lilo.conf
+			#	fi
+			#fi
 			#####	
 			
 		fi
@@ -909,7 +917,8 @@ EOF
 	#grub begin
 	if [ "$loadersetup" == "-auto" ]; then
 		grustatus=$GRUBERROR
-		installdevice=`echo $systempart | cut -c1-8`
+		#installdevice=`echo $systempart | cut -c1-8`
+		installdevice=$ROOTDEVICE
 		echo "Installing Grub Boot Loader on $installdevice"
 		efipartnum=`gdisk -l $installdevice 2>/dev/null | grep " EF00 " | sed 's/  */:/g' | cut -f2 -d:`
 		#if [ -d /sys/firmware/efi ] && [ ! -z "$efipartnum" ]; then #EFI
@@ -961,7 +970,17 @@ EOF
 			fi
 		#fi
 		#for dir in sys proc dev; do mount --bind /$dir /mnt/install/$dir; done
+		echo "Remove /boot/initrd.gz - no need for grub"
+		if [ -f /mnt/install/boot/initrd.gz ]; then
+		  rm /mnt/install/boot/initrd.gz
+		fi 
+		# Create initrd image for grub
+		echo "Create initrd image for grub"
+		chroot /mnt/install geninitrd
 		chroot /mnt/install grub-mkconfig -o /boot/grub/grub.cfg
+		if [ -f /mnt/install/boot/initrd.gz ]; then
+		  rm /mnt/install/boot/initrd.gz
+		fi  
 		#for dir in sys proc dev; do umount /mnt/install/$dir; done
 	fi
 		#####
